@@ -1,4 +1,4 @@
-/* $Id: paltex.c,v 1.6.2.1 2002/04/15 22:14:09 kschultz Exp $ */
+/* $Id: paltex.c,v 1.9 2002/07/22 13:45:31 brianp Exp $ */
 
 /*
  * Paletted texture demo.  Written by Brian Paul.
@@ -94,15 +94,16 @@ static void Init( void )
 {
 #define HEIGHT 8
 #define WIDTH 32
-   static char texture[HEIGHT][WIDTH] = {
-         "                                ",
-         "    MMM    EEEE   SSS    AAA    ",
-         "   M M M  E      S   S  A   A   ",
-         "   M M M  EEEE    SS    A   A   ",
-         "   M M M  E         SS  AAAAA   ",
-         "   M   M  E      S   S  A   A   ",
-         "   M   M   EEEE   SSS   A   A   ",
-         "                                "
+   /* 257 = HEIGHT * WIDTH + 1 (for trailing '\0') */
+   static char texture[257] = {"\
+                                \
+    MMM    EEEE   SSS    AAA    \
+   M M M  E      S   S  A   A   \
+   M M M  EEEE    SS    A   A   \
+   M M M  E         SS  AAAAA   \
+   M   M  E      S   S  A   A   \
+   M   M   EEEE   SSS   A   A   \
+                                "
       };
    GLubyte table[256][4];
 
@@ -161,7 +162,7 @@ static void Init( void )
                 0,                   /* border */
                 GL_COLOR_INDEX,      /* texture format */
                 GL_UNSIGNED_BYTE,    /* texture type */
-                texture);            /* teh texture */
+                texture);            /* the texture */
 #endif
 
    glTexParameteri(GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST);
